@@ -218,6 +218,8 @@ class Telemetrix(threading.Thread):
         else:
             print(f'Telemetrix4Arduino firmware version: {self.firmware_version[0]}.'
                   f'{self.firmware_version[1]}')
+        command = [PrivateConstants.ENABLE_ALL_REPORTS]
+        self._send_command(command)
 
     def _find_arduino(self):
         """
@@ -271,6 +273,7 @@ class Telemetrix(threading.Thread):
 
             print(f'\nWaiting {self.arduino_wait} seconds(arduino_wait) for Arduino devices to '
                   'reset...')
+            self._run_threads()
             time.sleep(self.arduino_wait)
 
             self._get_arduino_id()
@@ -833,7 +836,6 @@ class Telemetrix(threading.Thread):
         self._stop_threads()
 
         try:
-            self.disable_all_reporting()
             command = [PrivateConstants.STOP_ALL_REPORTS]
             self._send_command(command)
             time.sleep(.5)
